nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

ClkTuneCtrlStatus

Struct ClkTuneCtrlStatus 

#[repr(transparent)]
pub struct ClkTuneCtrlStatus(pub u32);
CLK Tuning Control and Status

Tuple Fields

0: u32

Implementations

Source

impl ClkTuneCtrlStatus

pub const fn dly_cell_set_post(&self) -> u8

Delay cells on the feedback clock between CLK_OUT and CLK_POST

pub const fn set_dly_cell_set_post(&mut self, val: u8)

Delay cells on the feedback clock between CLK_OUT and CLK_POST

pub const fn dly_cell_set_out(&self) -> u8

Delay cells on the feedback clock between CLK_PRE and CLK_OUT

pub const fn set_dly_cell_set_out(&mut self, val: u8)

Delay cells on the feedback clock between CLK_PRE and CLK_OUT

pub const fn dly_cell_set_pre(&self) -> u8

delay cells on the feedback clock between the feedback clock and CLK_PRE

pub const fn set_dly_cell_set_pre(&mut self, val: u8)

delay cells on the feedback clock between the feedback clock and CLK_PRE

pub const fn nxt_err(&self) -> bool

NXT error

pub const fn set_nxt_err(&mut self, val: bool)

NXT error

pub const fn tap_sel_post(&self) -> u8

Delay cells added on the feedback clock between CLK_OUT and CLK_POST

pub const fn set_tap_sel_post(&mut self, val: u8)

Delay cells added on the feedback clock between CLK_OUT and CLK_POST

pub const fn tap_sel_out(&self) -> u8

Delay cells added on the feedback clock between CLK_PRE and CLK_OUT

pub const fn set_tap_sel_out(&mut self, val: u8)

Delay cells added on the feedback clock between CLK_PRE and CLK_OUT

pub const fn tap_sel_pre(&self) -> u8

TAP_SEL_PRE

pub const fn set_tap_sel_pre(&mut self, val: u8)

TAP_SEL_PRE

pub const fn pre_err(&self) -> bool

PRE error

pub const fn set_pre_err(&mut self, val: bool)

PRE error