nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

ForceEvent

Struct ForceEvent 

#[repr(transparent)]
pub struct ForceEvent(pub u32);
Force Event

Tuple Fields

0: u32

Implementations

Source

impl ForceEvent

pub const fn fevtac12ne(&self) -> bool

Force event auto command 12 not executed

pub const fn set_fevtac12ne(&mut self, val: bool)

Force event auto command 12 not executed

pub const fn fevtac12toe(&self) -> bool

Force event auto command 12 time out error

pub const fn set_fevtac12toe(&mut self, val: bool)

Force event auto command 12 time out error

pub const fn fevtac12ce(&self) -> bool

Force event auto command 12 CRC error

pub const fn set_fevtac12ce(&mut self, val: bool)

Force event auto command 12 CRC error

pub const fn fevtac12ebe(&self) -> bool

Force event Auto Command 12 end bit error

pub const fn set_fevtac12ebe(&mut self, val: bool)

Force event Auto Command 12 end bit error

pub const fn fevtac12ie(&self) -> bool

Force event Auto Command 12 index error

pub const fn set_fevtac12ie(&mut self, val: bool)

Force event Auto Command 12 index error

pub const fn fevtcnibac12e(&self) -> bool

Force event command not executed by Auto Command 12 error

pub const fn set_fevtcnibac12e(&mut self, val: bool)

Force event command not executed by Auto Command 12 error

pub const fn fevtctoe(&self) -> bool

Force event command time out error

pub const fn set_fevtctoe(&mut self, val: bool)

Force event command time out error

pub const fn fevtcce(&self) -> bool

Force event command CRC error

pub const fn set_fevtcce(&mut self, val: bool)

Force event command CRC error

pub const fn fevtcebe(&self) -> bool

Force event command end bit error

pub const fn set_fevtcebe(&mut self, val: bool)

Force event command end bit error

pub const fn fevtcie(&self) -> bool

Force event command index error

pub const fn set_fevtcie(&mut self, val: bool)

Force event command index error

pub const fn fevtdtoe(&self) -> bool

Force event data time out error

pub const fn set_fevtdtoe(&mut self, val: bool)

Force event data time out error

pub const fn fevtdce(&self) -> bool

Force event data CRC error

pub const fn set_fevtdce(&mut self, val: bool)

Force event data CRC error

pub const fn fevtdebe(&self) -> bool

Force event data end bit error

pub const fn set_fevtdebe(&mut self, val: bool)

Force event data end bit error

pub const fn fevtac12e(&self) -> bool

Force event Auto Command 12 error

pub const fn set_fevtac12e(&mut self, val: bool)

Force event Auto Command 12 error

pub const fn fevttne(&self) -> bool

Force tuning error

pub const fn set_fevttne(&mut self, val: bool)

Force tuning error

pub const fn fevtdmae(&self) -> bool

Force event DMA error

pub const fn set_fevtdmae(&mut self, val: bool)

Force event DMA error

pub const fn fevtcint(&self) -> bool

Force event card interrupt

pub const fn set_fevtcint(&mut self, val: bool)

Force event card interrupt